"use client"
import { useRouter } from "next/navigation";
import { Card } from "@mui/material";
import Overlay from "../components/Overlay";
import { ImArrowUp } from "react-icons/im";
import { BiSearchAlt } from "react-icons/bi";
import { BiSolidMessageAlt } from "react-icons/bi";
import { HiPencilAlt } from "react-icons/hi";

export default function Help() {
  const router = useRouter()

  let info = [
    {
      image: <ImArrowUp className="text-ice-HC-dark " size="50%" />,
      title: "Publicando Recursos",
      questions: [
        "Por que enviar um recurso?",
        "Como publicar um recurso?",
        "Quais tipos de recursos e formatos de arquivo a plataforma aceita?"
      ],
      sectionPos: 0
    },
    {
      image: <BiSearchAlt className="text-ice-HC-dark " size="50%" />,
      title: "Encontrando Recursos",
      questions: [
        "Como fazer uma busca?",
        "Como filtrar os resultados?",
        "Como os recursos são ranqueados?"
      ],
      sectionPos: 1
    },
    {
      image: <BiSolidMessageAlt className="text-ice-HC-dark " size="50%" />,
      title: "Participando da  Rede",
      questions: [
        "Como comentar ou avaliar um recurso?",
        "Que tipo de comentário posso fazer sobre o recurso?"
      ],
      sectionPos: 2
    },
    {
      image: <HiPencilAlt className="text-ice-HC-dark " size="50%" />,
      title: "Gerenciando a Conta",
      questions: [
        "Por que se cadastrar?",
        "Como fazer meu cadastro?",
        "Como alterar minha senha?",
        "Como acessar a conta?",
        "Esqueci minha senha. O que fazer?"
      ],
      sectionPos: 3
    }
  ]

  return (
    <Overlay type="twoColumns">
      <div className="overflow-y-auto scrollbar-none ml-6 max-md:mb-24 h-screen">
        <div className="flex justify-center">
          <div className="text-darkGray-HC-white-underline text-2xl font-bold">Ajuda e Suporte</div>
        </div>
        <div className="flex justify-center mt-4">
          <p className="text-darkGray-HC-white-underline text-lg max-sm:text-center">Entre em contato para enviar dúvidas, sugestões ou críticas.</p>
        </div>
        <div className="flex justify-center mt-8">
          <div className=" max-xl:overflow-x-auto max-xl:ml-10 flex gap-10 max-sm:gap-4">
            {info?.map((item, index) => (
              <Card
              key={index}
                className="text-darkGray-HC-white bg-white-HC-dark  outline outline-1 outline-ice-HC-white w-[280px] h-[460px] min-w-[250px] max-2xl:w-[240px] max-sm:h-[410px] p-6"
                sx={{
                  display: "flex",
                  flexDirection: "column",
                  justifyContent: "flex-start",
                  backgroundColor: "#FFFFFF",
                  boxShadow: "none",
                }}
              >
                <div>
                  <div className="flex justify-center">
                    <div className="rounded-full bg-darkGray-HC-white w-20 h-20 flex justify-center items-center">
                      {item.image}
                    </div>
                  </div>
                  <div className="text-darkGray-HC-white mt-5 text-2xl font-bold flex text-center">
                    {item.title}
                  </div>
                </div>
                {item?.questions?.map((question, idx) => (
                  <button
                    key={idx}
                    onClick={() =>
                      router.push(`/topicosAjuda?section=${item.sectionPos}&pos=${idx}`)
                    }
                    className="flex text-start text-sm mt-4 ml-3 hover:turquoise-HC-underline underline"
                  >
                    {question}
                  </button>
                ))}
              </Card>
            ))}
          </div>
        </div>
        <div className="flex flex-col items-center rounded-xl px-10 max-sm:px-0  max-sm:py-6 mx-20 max-sm:mx-4 max-md:pb-28">
          <div className="text-darkGray-HC-white-underline mt-5 max-sm:mt-0 text-xl font-bold text-center">Não encontrou o que precisa?</div>
          <div className="text-darkGray-HC-white-underline text-md mt-4 ml-3 text-center">Entre em contato com nossa equipe</div>
          <button onClick={() => router.push("/contato")} className="mt-4 bg-turquoise text-lg text-white-HC-dark-underline p-2 px-4 rounded-lg hover:bg-turquoise-hover">Página de contato</button>
        </div>

      </div>

    </Overlay>
  )
}