"use client"

import { useEffect, useState } from "react";
import InfiniteScroll from "../components/InfiniteScroll";
import Overlay from "../components/Overlay";
import GroupButtonsFilters from "./GroupButtonsFilters";
import FiltersModal from "./FiltersModal";
import { useSearchParams, useRouter } from "next/navigation";

function tradutor(name) {
  switch (name) {
    case "LearningObject":
      return "Recursos"
    case "Collection":
      return "Coleções"
    case "MEC":
      return "MEC"
    case "User":
      return "Usuários"
    default:
      return
  }
}

function filterTradutor(name) {
  switch (name) {
    case "publicationdesc":
      return "recentes"
    case "score":
      return "relevantes"
    case "likes":
      return "colecionados"
    case "downloads":
      return "visualizados"
  }
}


/**
 * @param {Object} props
 * @param {string} props.name  informna se é recursos, coleções ou MEC
 * @param {string} props.inputFilter
 */
export default function Content({ name, inputFilter, searchPage }) {
  const [titlePage, setTitlePage] = useState("Recentes");
  const [newSize, setNewSize] = useState(false);
  const [activeFilters, setActiveFilters] = useState(false)
  const router = useRouter()


  const [filterState, setFilterState] = useState({
    languages: [], // em ids
    searchClass: searchPage ? searchPage : "LearningObject", // lo, user, collection
    subjects: [], // matéria (portugues, matemática)
    objectTypes: [], // pdf, video, etc
    educationalStages: [], // ensino fundamental, médio, etc
    query: "*", // string de busca
    order: "publicationdesc", // ordem
    title: "Recentes"
  });

  useEffect(() => {
    setTitlePage(filterState.title)
  }, [filterState])

  const itemsBySearchClass = {};
  const setItemsBySearchClass = {};
  const abortControllerBySearchClass = {};
  const setAbortControllerBySearchClass = {};

  [abortControllerBySearchClass["LearningObject"], setAbortControllerBySearchClass["LearningObject"]] = useState(new AbortController());
  [abortControllerBySearchClass["Collection"], setAbortControllerBySearchClass["Collection"]] = useState(new AbortController());
  [abortControllerBySearchClass["User"], setAbortControllerBySearchClass["User"]] = useState(new AbortController());
  [abortControllerBySearchClass["MEC"], setAbortControllerBySearchClass["MEC"]] = useState(new AbortController());
  [itemsBySearchClass["LearningObject"], setItemsBySearchClass["LearningObject"]] = useState([]);
  [itemsBySearchClass["Collection"], setItemsBySearchClass["Collection"]] = useState([]);
  [itemsBySearchClass["User"], setItemsBySearchClass["User"]] = useState([]);
  [itemsBySearchClass["MEC"], setItemsBySearchClass["MEC"]] = useState([]);

  useEffect(() => {
    for (const [searchClass, abortController] of Object.entries(abortControllerBySearchClass)) {
      setItemsBySearchClass[searchClass]([]);
      abortController.abort();
      if (searchClass === searchPage) {
        setAbortControllerBySearchClass[searchClass](new AbortController());
      }
    }
    setFilterState(old => { return { ...old, searchClass: searchPage, query: (inputFilter === null ? "*" : inputFilter) } })
  }, [inputFilter, searchPage])
  {/* GroupButtonsFilters: Botões para seleção do tipo de filtro usado (selectFilter) */ }
  //caso MEC não apresenta o GroupButtonsFilters pois não há conteudo suficiente para ser filtrado
  return (
    <Overlay filterState={filterState} setFilterState={setFilterState} setNewSize={setNewSize} newSize={newSize} type="twoColumns">
      <>
        {(filterState.searchClass !== "MEC" && filterState.searchClass != "User") ?
          (
            <div>
              <div className="pl-3 max-sm:pl-1 fixed w-full  bg-fundo bg-repeat bg-fixed max-md:ml-3 z-30" >
                <h1 className="text-2xl ml-5 font-bold text-darkGray-HC-white">
                  {tradutor(filterState.searchClass)} {(filterState.order === "title") ? "por Ordem alfabética" : " mais " + titlePage}
                </h1>
                <div className={`flex w-full justify-between`}>
                  <GroupButtonsFilters pageName={searchPage} activeFilters={activeFilters} setActiveFilters={setActiveFilters} filterState={filterState} setFilterState={setFilterState} setItems={setItemsBySearchClass[filterState.searchClass]} />
                </div>
              </div>
              {/*caso tenha mais de 15 filtros ativos, o InfiniteScroll é renderizado com um padding-top maior, esse valor foi definido empiricamente*/}
              <div className="pt-36 max-md:pt-28">
                <InfiniteScroll filterState={filterState} setNewSize={setNewSize} setItems={setItemsBySearchClass[filterState.searchClass]} items={itemsBySearchClass[filterState.searchClass]} abortController={abortControllerBySearchClass[filterState.searchClass]} />
              </div>
            </div>
          )
          :
          <>
            <InfiniteScroll filterState={filterState} setNewSize={setNewSize} setItems={setItemsBySearchClass[filterState.searchClass]} items={itemsBySearchClass[filterState.searchClass]} abortController={abortControllerBySearchClass[filterState.searchClass]} />
          </>
        }
      </>
    </Overlay>
  )
}