import { useState } from "react";
import ButtonsPages from "./ButtonsPages";
import { Button, Divider } from "@mui/material";
import FormGroup from '@mui/material/FormGroup';
import FormControlLabel from '@mui/material/FormControlLabel';
import Checkbox from '@mui/material/Checkbox';
import { objectTypes } from "./ObjectTypes";
import Image from "next/image";
import FieldLabel from "../publicar/components/FieldLabel";
import { useRouter, useSearchParams } from "next/navigation";
import { Search } from "@mui/icons-material";
import LocalLibraryIcon from "@mui/icons-material/LocalLibrary";
import CustomCheckbox from "../publicar/components/CustomCheckbox";
import CloseIcon from '@mui/icons-material/Close';



export default function FormFilters({
    scholarityLevelsAvailable,
    languagesAvailable,
    filterState,
    handleClose,
    setFilterState,
    setItems,
    activeFilters,
    setActiveFilters,
    subjectsAvailable
}) {
    const router = useRouter()
    const searchParams = useSearchParams()
    const [filterStateDraft, setFilterStateDraft] = useState(() => structuredClone(filterState))

    const handleLanguagesChange = (e) => {
        const lang = JSON.parse(e.target.value);

        if (filterStateDraft.languages.some((l) => l.name === lang.name)) {
            setFilterStateDraft(old => {
                return {
                    ...old,
                    languages: old.languages.filter((language) => (language.name !== lang.name))
                }
            })
            return;
        }

        setFilterStateDraft(old => {
            return {
                ...old,
                languages: [...old.languages, lang],
            }
        })
    };


    const handleEducationalStage = (e) => {
        const educationalStage = JSON.parse(e.target.value);
        if (filterStateDraft.educationalStages.some(stage => stage.id === educationalStage.id)) {
            setFilterStateDraft(old => {
                return {
                    ...old,
                    educationalStages: old.educationalStages.filter((obj) => (obj.id !== educationalStage.id))
                }
            })
            return;
        }

        setFilterStateDraft(old => {
            return {
                ...old,
                educationalStages: [...old.educationalStages, educationalStage],
            }
        })
    };

    const handlePageChange = (page) => {
        if (filterStateDraft.searchClass !== page)
            setFilterStateDraft(old => { return { ...old, searchClass: page } });
    };

    const handleObjectType = (object) => {
        if (filterStateDraft.objectTypes.some(obj => obj.id === object.id)) {
            setFilterStateDraft(old => {
                return {
                    ...old,
                    objectTypes: old.objectTypes.filter((obj) => (obj.id !== object.id))
                }
            })
        }
        else {
            setFilterStateDraft(old => {
                return {
                    ...old,
                    objectTypes: [...old.objectTypes, object],
                }
            })
        };
    };

    const handleResetFilters = (e) => {
        setItems([])

        const filterStateLixo = {
            languages: [], // em ids
            searchClass: "LearningObject", // lo, user, collection
            subjects: [], // matéria (portugues, matemática)
            objectTypes: [], // pdf, video, etc
            educationalStages: [], // ensino fundamental, médio, etc
            query: "*", // string de busca
            order: "publicationdesc" // ordem
        };
        setFilterState(structuredClone(filterStateLixo));
        setFilterStateDraft(structuredClone(filterStateLixo))
        handleClose()

    }

    const handleSubmit = (e) => {
        e.preventDefault()

        if (JSON.stringify(filterState) !== JSON.stringify(filterStateDraft))
            setActiveFilters(true)



        if (filterStateDraft.subjects.length > 0)
            setActiveFilters(true)

        setItems([])
        setFilterState(structuredClone(filterStateDraft));
        router.push(`/busca?page=${filterStateDraft.searchClass}`)



        handleClose()

    }

    const handleFilterSubject = (e) => {
        const index = JSON.parse(e.target.value);


        if (filterStateDraft.subjects.some((l) => l.name === index.name)) {
            setFilterStateDraft(old => {
                return {
                    ...old,
                    subjects: old.subjects.filter((subject) => (subject.name !== index.name))
                }
            })
            return;
        }


        setFilterStateDraft(old => {
            return {
                ...old,
                subjects: [...old.subjects, index],
            }
        })

    };

    return (
        <>
            <form className="mt-12" onSubmit={handleSubmit} onKeyDown={(e) => { if (e.key === "Enter") e.preventDefault() }}>
                <Divider />
                <ButtonsPages searchPage={filterStateDraft.searchClass} handlePageChange={handlePageChange} />
                <Divider />

                <p className="font-bold text-darkGray-HC-white text-xl py-2">
                    Tipo de recurso
                </p>
                <div className="flex flex-wrap justify-start ml-8">
                    {objectTypes.map((object, index) => {
                        return (
                            <div
                                key={index}
                                onClick={() => handleObjectType(object)}
                                className={`
                                ${filterStateDraft.objectTypes.some(obj => obj.id === object.id)
                                        ? "border-2 border-turquoise-HC-white bg-lightGray-HC-white text-turquoise-HC-dark-underline"
                                        : "bg-ice-HC-dark text-turquoise-HC-white-underline"}
                                
                                hover:bg-lightGray-HC-white
                                hover:text-turquoise-HC-dark
                                hover:cursor-pointer
                              
                                
                              
                                h-20 w-20
                                max-lg:h-20 max-lg:w-20
                              
                                flex flex-col items-center justify-center
                                m-3 p-2 text-center
                              
                                rounded-lg
                                outline outline-1 outline-ice-HC-white
                              `}
                            >
                                <div
                                    alt={object.name}
                                    className="w-12 h-12 max-lg:w-8 max-sm:hidden max-lg:h-8 fill-current"
                                    dangerouslySetInnerHTML={{ __html: object.image }}
                                ></div>
                                {/* <Image alt={object.name} height={0} width={0} className="w-10 h-10 max-lg:w-8 max-lg:h-8" src={object.image} /> */}
                                <span className="text-xs max-lg:text-xs">{object.name}</span>
                            </div>
                        )
                    })}
                </div>

                <Divider />

                <FieldLabel
                    name="Nível de ensino"
                    description="(Selecione uma ou mais opções)"
                />
                <FormGroup className="flex flex-wrap mt-5 mb-10">
                    {scholarityLevelsAvailable.map((sl, index) => (
                        <FormControlLabel
                            onChange={handleEducationalStage}
                            key={index}
                            control={< CustomCheckbox checked={filterStateDraft.educationalStages.some(obj => sl.id === obj.id)} />}
                            value={JSON.stringify(sl)}
                            label={<span className="text-darkGray-HC-white">{sl.name}</span>}
                        />
                    ))}
                </FormGroup>

                <Divider />

                <FieldLabel name="Idiomas do Recurso" />
                <FormGroup className="flex flex-wrap mb-5" row>
                    {languagesAvailable?.map((language, index) => (
                        <FormControlLabel
                            className="w-64"
                            onChange={handleLanguagesChange}
                            key={index}
                            control={< CustomCheckbox checked={filterStateDraft.languages.some(l => l.name === language.name)} />}
                            value={JSON.stringify(language)}
                            label={<span className="text-darkGray-HC-white">{language.name}</span>}
                        />
                    ))}
                </FormGroup>

                <Divider />

                <FieldLabel name="Grandes Áreas" />

                <FormGroup className="flex flex-wrap mb-5 " row >
                    {subjectsAvailable?.map((subj, index) => (
                        <FormControlLabel
                            className="w-64"
                            onChange={handleFilterSubject}
                            key={index}
                            control={< CustomCheckbox checked={filterStateDraft.subjects.some(s => s.name === subj.name)} />}
                            value={JSON.stringify(subj)}
                            label={<span className="text-darkGray-HC-white">{subj.name}</span>}
                        />
                    ))}
                </FormGroup>

                <div className="fixed bottom-[10%] z-20 bg-white-HC-dark p-4 w-[56%] flex justify-end">
                    <div className="flex">
                        <Button onClick={handleResetFilters} className="text-darkGray-HC-white-underline normal-case font-semibold text-base hover:bg-ice-HC-dark cursor-pointer mx-2 outline outline-1 outline-ice-HC-white">Remover filtros</Button>
                        <Button type="submit" className="bg-turquoise-HC-white hover:bg-darkTurquoise-HC-dark text-white-HC-dark-underline hover:text-white normal-case font-semibold text-base hover:bg-turquoise-hover cursor-pointer outline outline-1 outline-ice-HC-white">Mostrar resultados</Button>
                    </div>
                </div>
            </form>

        </>
    )
}