import { Button } from "@mui/material";
import { usePathname } from "next/navigation";
import FiltersModal from "./FiltersModal";
import { Chip } from "@mui/material";
import { useState, useEffect } from "react";
import mecredApi from "@/axiosConfig";
import { useSearchParams } from 'next/navigation';
import { useRouter } from "next/navigation";
import NavigateNextIcon from '@mui/icons-material/NavigateNext';


/**
 * 
 * @param {Object} props
 * @param {Function} props.setTitlePage
 * @param {Function} props.setSelectFilter
 * @param {String} props.selectFilter filtro selecionado (ex:score)
 * @returns grupo de botões de filtros
*/
export default function GroupButtonsFilters({ pageName, filterState, setFilterState, setItems, activeFilters, setActiveFilters }) {
    const [scholarityLevelsAvailable, setScholarityLevelAvailable] = useState([]);
    const [languagesAvailable, setLanguagesAvailable] = useState([]);
    const [subjectsAvailable, setSubjectsAvailable] = useState([]);


    useEffect(() => {
        mecredApi.get("/educational_stages")
            .then((response) => { setScholarityLevelAvailable(response.data) });

        mecredApi.get("/languages")
            .then((response) => { setLanguagesAvailable(response.data) });

        mecredApi
            .get("/subjects")
            .then(({ data }) => {
                setSubjectsAvailable(data);
            })
    }, []);

    const pathname = usePathname();
    const atalhos = [
        {
            title: 'Recentes',
            titlePage: 'Recentes',
            order: 'publicationdesc'
        },
        {
            title: 'Relevantes',
            titlePage: 'Relevantes',
            order: 'score'
        },
        pageName === "Collection" ? null :
            {
                title: 'Colecionados',
                titlePage: 'Colecionados',
                order: 'likes'
            },
        pageName === "LearningObject" ?
            {
                title: 'Visualizados',
                titlePage: 'visualizados',
                //filtrando por "mais baixados" pq os "mais visualizados" não esta funcionando direito
                order: 'downloads'
            }
            :
            {
                title: 'Visualizadas',
                titlePage: 'visualizadas',
                //filtrando por "mais baixados" pq os "mais visualizados" não esta funcionando direito
                order: 'downloads'
            },
        {
            title: 'Alfabética',
            titlePage: 'Alfabética',
            order: 'title'
        }
    ]


    useEffect(() => {
        if ((filterState.objectTypes.length === 0) && (filterState.languages.length === 0) && (filterState.educationalStages.length === 0) && (filterState.subjects.length === 0))
            setActiveFilters(false)

    }, [filterState, setActiveFilters])

    const handleDeletObjectType = (object) => {
        setFilterState(old => {
            return {
                ...old,
                objectTypes: old.objectTypes.filter((obj) => (obj.id !== object.id))
            }
        })


    };

    const handleDeletLanguages = (object) => {
        setFilterState(old => {
            return {
                ...old,
                languages: old.languages.filter((obj) => (obj.id !== object.id))
            }
        })
    };

    const handleDeletEducationalStages = (object) => {
        setFilterState(old => {
            return {
                ...old,
                educationalStages: old.educationalStages.filter((obj) => (obj.id !== object.id))
            }
        })
    };

    const handleDeletSubjects = (object) => {
        setFilterState(old => {
            return {
                ...old,
                subjects: old.subjects.filter((obj) => (obj.id !== object.id))
            }
        })
    };

    return (
        <div className="flex flex-col w-full">
            <div className="flex justify-between pb-2 max-md:pb-0 px-4 overflow-x-scroll no-scrollbar w-full pr-32 max-sm:pr-0 animate-scrollHint">
                <div className="flex shrink max-sm:flex-row-reverse">
                    {atalhos.map((item, index) => {
                        return (
                            item ?
                                <div key={index}>
                                    <Button className={`normal-case ${filterState.order === item.order ? "bg-turquoise-HC-white hover:bg-darkTurquoise-HC-dark text-white-HC-dark-underline hover:text-white " : "bg-ice-HC-dark hover:bg-lightGray-HC-white hover:text-darkGray-HC-dark"} mt-2 outline outline-1 outline-ice-HC-white text-base rounded-lg min-w-32 font-medium mx-1 text-darkGray-HC-white-underline bg-ice-HC-dark`}
                                        onClick={() => {
                                            setFilterState(old => { return { ...old, order: item.order, title: item.title } })
                                        }}
                                    > {item.title}</Button>
                                </div> : null
                        )
                    })}
                    <FiltersModal
                        activeFilters={activeFilters}
                        setActiveFilters={setActiveFilters}
                        languagesAvailable={languagesAvailable}
                        scholarityLevelsAvailable={scholarityLevelsAvailable}
                        filterState={filterState}
                        setFilterState={setFilterState}
                        setItems={setItems}
                        subjectsAvailable={subjectsAvailable}
                    />
                </div>
            </div>

            <div>
                <div className={`flex sm:mr-24 sm:flex-wrap ml-5 h-[40px] bg-fundo bg-repeat bg-fixed max-sm:overflow-x-scroll no-scrollbar `}>
                    {filterState.educationalStages.map((tag, index) => (
                        <Chip className="mr-1  border-none bg-orange text-white-HC-dark-underline" key={index} label={tag.name} variant="outlined" onDelete={() => handleDeletEducationalStages(tag)} />
                    ))}
                    {filterState.languages.map((tag, index) => (
                        <Chip className="mr-1  border-none bg-orange text-white-HC-dark-underline" key={index} label={tag.name} variant="outlined" onDelete={() => handleDeletLanguages(tag)} />
                    ))}
                    {filterState.objectTypes.map((tag, index) => (
                        <Chip className="mr-1  border-none bg-orange text-white-HC-dark-underline" key={index} label={tag.name} variant="outlined" onDelete={() => handleDeletObjectType(tag)} />
                    ))}
                    {filterState.subjects.map((tag, index) => (
                        <Chip className="mr-1  border-none bg-orange text-white-HC-dark-underline" key={index} label={tag.name} variant="outlined" onDelete={() => handleDeletSubjects(tag)} />
                    ))}

                </div>
            </div>
        </div>
    );
}