"use client";
import { useEffect, useState } from "react";
import Cards from "./Cards";
import { useRouter } from "next/navigation"
/**
 * Retorna na tela uma coleção
 * @param {Array.<Object>} data - recursos da coleção
 * @param {number} cardsPerRow - quantidade de cards que cabem na linha 
 */
export default function GroupCardsCollections({ data, cardsPerRow, collectionId }) {
  const [expanded, setExpanded] = useState(false);
  const [showButton, setShowButton] = useState(false);
  const router = useRouter()

  console.log(data)

  const handleResize = (data) => {
    setShowButton(data?.length > cardsPerRow);
  };

  const toggleContent = () => {
    setExpanded(!expanded);
  };

  useEffect(() => {
    handleResize(data);
  }), [cardsPerRow];

  return (

    <div className="flex flex-col">
      <div className="mx-1 flex flex-col">
        <div id="contentSize" className={`flex content flex-wrap max-sm:justify-center mb-4 max-sm:ml-0  md:ml-0 ${expanded ? "" : "overflow-y-hidden h-[270px]"}`}>

        {data?.length !== 0 ? data?.sort((a,b) => a.position - b.position).map((item, index) => {
            return (
              <Cards
                collectionSource={collectionId}
                key={index}
                id={item['collectionable']['id']}
                title={item["collectionable"]["name"]}
                author={item["collectionable"]["publisher"]["name"]}
                authorId={item["collectionable"]["publisher"]["id"]}
                avatar={item["collectionable"]["publisher"]["avatar"]}
                image={item["collectionable"]["thumbnail"]}
                updated_at={item["collectionable"]["updated_at"]}
              />
            );
          })
            :
            <div className="flex flex-col justify-center w-full items-center">
              <p className="text-darkGray-HC-white-underline text-xl font-bold">Coleção Vazia</p>
              <button onClick={() => router.push(`/busca?page=LearningObject`)} className="text-darkGray-HC-white-underline text-sm font-bold">Adicione novos recursos!</button>
            </div>
          }
        </div>
      </div>
      <>
        {/*mostra botão de ver mais caso os recursos de uma coleção cabem em mais de uma linha */}
        {showButton ?
          (
            <button
                fullWidth
                disableElevation
                variant="outlined"
                className="group hover:bg-lightGray-HC-white text-darkGray-HC-white hover:text-darkGray-HC-dark transition-all duration-300 -ml-4 py-2 border-hidden rounded-xl normal-case flex justify-center items-center gap-2"
                onClick={toggleContent}
            >
                <p className="px-4 text-lg rounded-md">
                    {expanded ? "Ver menos" : "Ver mais"}
                </p>
                <span
                    className={`transform transition-transform duration-300 ${
                        expanded ? "rotate-180" : "rotate-0"
                    }`}
                >
                    ▼
                </span>
            </button>
          ) : null}

      </>
    </div >
  );
}
