import * as React from "react";
import Box from "@mui/material/Box";
import Avatar from "@mui/material/Avatar";
import Menu from "@mui/material/Menu";
import MenuItem from "@mui/material/MenuItem";
import IconButton from "@mui/material/IconButton";
import { useState, useEffect } from "react";
import { useRouter } from "next/navigation";
import Link from "next/link";
import {
  getStoredValue,
  removeFromLocalStorage,
} from "../handlers/localStorageHandler";
import { isLoggedIn } from "../handlers/loginHandler";
import AccountCircleRoundedIcon from '@mui/icons-material/AccountCircleRounded';
import SettingsRoundedIcon from '@mui/icons-material/SettingsRounded';
import PrivacyTipRoundedIcon from '@mui/icons-material/PrivacyTipRounded';
import HelpRoundedIcon from '@mui/icons-material/HelpRounded';
import AccessibilityNewRoundedIcon from '@mui/icons-material/AccessibilityNewRounded';
import FeedbackRoundedIcon from '@mui/icons-material/FeedbackRounded';
import EmailRoundedIcon from '@mui/icons-material/EmailRounded';
import { mecredURL } from "@/axiosConfig";

const items = [
  // {
  //   label: "Configurações",
  //   href: "/",
  //   icon: SettingsRoundedIcon,
  //   target: 0
  // },
  // {
  //   label: "Privacidade",
  //   href: "/",
  //   icon: PrivacyTipRoundedIcon,
  //   target: 1
  // },
  {
    label: "Ajuda e Suporte",
    href: "/ajuda",
    icon: HelpRoundedIcon,
    target: 2
  },
  {
    label: "Entre em Contato",
    href: "/contato",
    icon: EmailRoundedIcon,
    target: 3
  }
  // {
  //   label: "Tela e Acessibilidade",
  //   href: "/",
  //   icon: AccessibilityNewRoundedIcon,
  //   target: 3
  // }
];

function getRandomBg(id) {
  const colors = [
    "bg-turquoise",
    "bg-orange",
    "bg-turquoise-hover",
    "bg-darkOrange-HC-gray ",
    "bg-violet",
    "bg-pink",
    "bg-red",
    "bg-darkGray-HC-white",
    "bg-darkGray-HC-white-click",
    "bg-ice-HC-dark ",
    "bg-darkGray-HC-white",
    "bg-darkGray-HC-white",
    "bg-turquoise-HC-dark",
  ]

  return colors[id % colors.length];
}

/**
 * 
 * @returns menu do usuário
 */
export default function AccountMenu() {
  const [anchorEl, setAnchorEl] = useState(null);
  const [userData, setUserData] = useState({});
  const [id, setId] = useState(null);
  const [logged, setLogged] = useState(false);
  const open = Boolean(anchorEl);

  const router = useRouter();

  useEffect(() => {
    if (isLoggedIn()) {
      let data = JSON.parse(getStoredValue("user_data"));
      setId(data["id"]);
    }
    setLogged(isLoggedIn());
  }, []);

  const handleClick = (event) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  const handleLogout = () => {
    removeFromLocalStorage("access_token");
    removeFromLocalStorage("user_data");
    removeFromLocalStorage("uid");
    removeFromLocalStorage("expiry");
    removeFromLocalStorage("token-type");
    removeFromLocalStorage("client");
    window.location.reload();
  };

  useEffect(() => {
    let token = getStoredValue("access_token");
    if (token) {
      let user = getStoredValue("user_data");
      setUserData(JSON.parse(user));
    }
  }, []);

  return (
    <>
      {logged ? (
        <Box className="mr-14 flex align-center">
          <IconButton
            onClick={handleClick}
            size="large"
            aria-controls={open ? "account-menu" : undefined}
            aria-haspopup="true"
            aria-expanded={open ? "true" : undefined}
            title="Meu Perfil"
            alt="Acessar meu perfil"
          >
            {(userData["avatar_file_name"] === "") || (userData["avatar_file_name"] === null) ? (
              <div className={`flex items-center max-sm:-ml-px justify-center text-xl font-bold text-ice-HC-dark bg-turquoise-HC-white rounded-full h-[38px] w-[38px] ${getRandomBg(userData["id"])}`} >{userData["name"][0]}</div>
            ) : (
              <Avatar
                src={
                  mecredURL +
                  userData["avatar_file_name"]
                }
                sx={{ width: 38, height: 38 }}
              />
            )}
          </IconButton>
        </Box>
      )
        :
        (
          <Link href={"/entrar"}>
            {" "}
            <IconButton size="large">
              <Avatar sx={{ width: 38, height: 38 }} className="mt-1" />
            </IconButton>
          </Link>
        )}
      <Menu
        anchorEl={anchorEl}
        id="account-menu"
        open={open}
        onClose={handleClose}
        onClick={handleClose}
        transformOrigin={{ horizontal: "right", vertical: "top" }}
        anchorOrigin={{ horizontal: "right", vertical: "bottom" }}
        sx={{ 
          backgroundColor: 'transparent',
          '& .MuiPaper-root': {
              backgroundColor: 'var(--ice-HC-dark)',
              border: '2px solid var(--ice-HC-white)',
              borderRadius: '8px',
          }
      }}
      >
        <MenuItem className="ml-1" sx={{ 'pointer-events': 'none' }} >
          {(userData["avatar_file_name"] === "") || (userData["avatar_file_name"] === null) ? (
            <div className={`flex items-center justify-center pt-1 text-xl font-bold text-ice-HC-dark bg-turquoise-HC-white rounded-full h-[38px] w-[38px] ${getRandomBg(userData["id"])}`} >{userData["name"][0]}</div>
          ) : (
            <Avatar
              src={
                mecredURL +
                userData["avatar_file_name"]
              }
              sx={{ width: 38, height: 38 }}
            />
          )}
          <div className="grid grid-rows-2 text-darkGray-HC-white ml-4 mt-2 grid-flow-row">
            <p className="row-span-1"> {userData["name"]} </p>
            <p className="row-span-2 text-xs"> {userData["uid"]} </p>
          </div>
        </MenuItem>
        <hr className="border-mediumGray-HC-white h-1 my-2 "/>
        <Link href={`/perfil/${id}`} className="flex mb-2">
          <MenuItem >
            <AccountCircleRoundedIcon className="mr-4 text-turquoise-HC-white text-3xl" />
            <p className="text-turquoise-HC-white-underline ">Acessar meu Perfil</p>
          </MenuItem>
        </Link>
        <hr className="border-mediumGray-HC-white h-1 my-2 "/>
        {items.map((item, index) => {
          return (
            <Link href={item.href} key={index}>
              <MenuItem title="Ainda não disponível">
                <item.icon className="text-darkGray-HC-white mr-4 text-3xl" />
                <p className="text-darkGray-HC-white">{item.label}</p>
              </MenuItem>
            </Link>
          );
        })}
        <hr className="border-mediumGray-HC-white h-1 my-2 "/>
        <MenuItem className="flex items-center justify-center text-darkGray-HC-white-underline text-sm" onClick={handleLogout}>
          <p>Sair da minha conta</p>
        </MenuItem>
      </Menu>
    </>
  );
}
