import * as React from 'react';
import { useState, useEffect } from 'react';
import NeedLoginModal from './needLoginModal';
import { isLoggedIn } from "../handlers/loginHandler";
import FileUploadIcon from '@mui/icons-material/FileUpload';
import CollectionsBookmarkIcon from "@mui/icons-material/CollectionsBookmark";
import SubjectIcon from "@mui/icons-material/Subject";
import EmailRoundedIcon from '@mui/icons-material/EmailRounded';
import LogoutRounded from '@mui/icons-material/LogoutRounded';
import HelpIcon from "@mui/icons-material/Help";
import VerifiedIcon from "@mui/icons-material/Verified";
import { Person } from "@mui/icons-material";
import SearchIcon from '@mui/icons-material/Search';
import { usePathname, useRouter, useSearchParams } from "next/navigation";
import {
    getStoredValue,
    removeFromLocalStorage,
  } from "../handlers/localStorageHandler";


export default function NavigationBar({ mobileSearch}) {

    const [needLoginOpen, setNeedLoginOpen] = useState(false);
    const pathname = usePathname();
    let searchParams = useSearchParams();
    const page = searchParams.get('page');
    const [id, setId] = useState(null);

    useEffect(() => {
        if (isLoggedIn()) {
            let data = JSON.parse(getStoredValue("user_data"));
            setId(data["id"]);
        }
    }, []);

    const handleOpenLoggin = (e) => {

        if (!isLoggedIn()) {
            e.preventDefault();
            setNeedLoginOpen(true);
        }
    };

    const handleLogout = () => {
        removeFromLocalStorage("access_token");
        removeFromLocalStorage("user_data");
        removeFromLocalStorage("uid");
        removeFromLocalStorage("expiry");
        removeFromLocalStorage("token-type");
        removeFromLocalStorage("client");
        window.location.reload();
    };

    const navItems = [
        { label: "Pesquisar", href: "#", icon: SearchIcon },
        { label: "Recursos", href: "/busca?page=LearningObject", icon: SubjectIcon },
        { label: "Coleções", href: "/busca?page=Collection", icon: CollectionsBookmarkIcon },
        { label: "Publicar", href: "/publicar", icon: FileUploadIcon },
        { label: "MEC", href: "/busca?page=MEC", icon: VerifiedIcon },
        { label: "Perfil", href: "/perfil", icon: Person },
        { label: "Sobre", href: "/sobre", icon: HelpIcon },
        { label: "Contato", href: "/contato", icon: EmailRoundedIcon },
        { label: "Sair", href: "", icon: LogoutRounded},
    ]

    const handleToggleMobileSearch = (e) => {
        e.preventDefault();
        mobileSearch.setSearchIsClicked((prevState) => !prevState); // Alterna a exibição da pesquisa
    };

    return (
        <>
            <NeedLoginModal open={needLoginOpen} setOpen={setNeedLoginOpen} />

            <nav className="bg-lightGray  h-50 outline outline-1 outline-ice-HC-white text-darkGray-HC-white font-light fixed bottom-0 left-0 w-full z-10">
                <ul className="flex justify-between overflow-x-auto no-scrollbar animate-scrollHint">
                {navItems.map((item, index) => {
                    const isPublishRoute = item.href === "/publicar";
                    const isPerfilRoute = item.href === "/perfil";
                    const isSearchButton = item.label === "Pesquisar";
                    const isLogout = item.label === "Sair";

                    const isActive =
                        (page === item.href.split("page=")[1]) ||
                        (pathname === item.href) ||
                        (mobileSearch.searchIsClicked && item.label === "Pesquisar");

                    return (
                        <li key={index} className="flex w-20 flex-col items-center justify-center p-3">
                        <a
                            href={isLogout ? "#" : (
                            isPublishRoute ? (isLoggedIn() ? "/publicar" : "") :
                            isPerfilRoute ? (isLoggedIn() ? `/perfil/${id}` : "") :
                            item.href
                            )}
                            onClick={
                            isLogout ? (e) => { e.preventDefault(); handleLogout(); } :
                            isPublishRoute || isPerfilRoute ? (e) => handleOpenLoggin(e) :
                            isSearchButton ? (e) => handleToggleMobileSearch(e) :
                            undefined
                            }
                            className={`text-center rounded-md transition-all ${
                            isActive ? "font-bold text-black" : ""
                            }`}
                        >
                            <item.icon className={`cursor-pointer text-3xl ${isActive ? "text-black font-bold" : ""}`} />
                            <span className={`cursor-pointer text-xs ${isActive ? "text-black font-bold" : ""}`}>
                            {item.label}
                            </span>
                        </a>
                        </li>
                    );
                })}
                </ul>
            </nav>
        </>
    )
}