"use client";

import Link from "next/link";
import CollectionsBookmarkIcon from "@mui/icons-material/CollectionsBookmark";
import SubjectIcon from "@mui/icons-material/Subject";
import EmailRoundedIcon from '@mui/icons-material/EmailRounded';
import HelpIcon from "@mui/icons-material/Help";
import { useEffect, useState } from "react";
import VerifiedIcon from "@mui/icons-material/Verified";
import { usePathname, useSearchParams } from "next/navigation";
import { Person } from "@mui/icons-material";
import FileUploadIcon from '@mui/icons-material/FileUpload';
import { isLoggedIn } from "../handlers/loginHandler";
import NeedLoginModal from "./needLoginModal";
import {
  getStoredValue,
} from "../handlers/localStorageHandler";

/**
 * @param {Object} props
 * @param {Function} props.setFilterSubject
 * @param {Boolean} props.openMenu
 */

const acessoRapido = [
  {
    title: "Publicar",
    icon: FileUploadIcon,
    href: "/publicar",
    id: "Publicar Recurso",
  },
  {
    title: "MEC",
    icon: VerifiedIcon,
    href: "MEC",
    id: "MEC",
  },

  {
    title: "Coleções",
    icon: CollectionsBookmarkIcon,
    href: "Collection",
    id: "Coleções",
  },
  {
    title: "Recursos",
    icon: SubjectIcon,
    href: "LearningObject",
    id: "Recursos",
  },
  {
    title: "Perfil",
    icon: Person,
    href: "/perfil",
    id: "Perfil",
  },
  {
    title: "Sobre",
    icon: HelpIcon,
    href: "/sobre",
    id: "Sobre",
  },
  {
    title: "Contato",
    icon: EmailRoundedIcon,
    href: "/contato",
    id: "Contato",
  }
];

function tradutor(name) {
  switch (name) {
    case "LearningObject":
      return "Recursos"
    case "Collection":
      return "Coleções"
    case "MEC":
      return "MEC"
    case "/perfil":
      return "Perfil"
    case "/publicar":
      return "Publicar Recurso"
    case "/contato":
      return "Entre em contato"
    default:
      return "Sobre"
  }
}


export default function SideBar({ setFilterState, filterState }) {
  let searchParams = useSearchParams();
  const page = searchParams.get('page')
  const pathname = usePathname();

  const getHref = (href) => {
    switch (href) {
      case "/sobre":
        return "/sobre";
      case "/publicar":
        return "/publicar";
      case "/contato":
        return "/contato"
      case "/perfil":
        return `/perfil/${id}`;
      default:
        return `/busca?page=${href}`;
    }
  };

  const [needLoginOpen, setNeedLoginOpen] = useState(false);


  const handleOpenLogin = () => {

    if (!isLoggedIn()) {
      setNeedLoginOpen(true);
    }
  };

  const [id, setId] = useState(null);

  useEffect(() => {
    if (isLoggedIn()) {
      let data = JSON.parse(getStoredValue("user_data"));
      setId(data["id"]);
    }
  }, []);

  return (
    <>
      <NeedLoginModal open={needLoginOpen} setOpen={setNeedLoginOpen} />

      <div className="max-md:hidden min-h-0 overflow-y-auto flex flex-col text-darkGray-HC-white-underline font-light">
        <div className="flex flex-col justify-start items-center gap-3 w-full ">
          {acessoRapido.map((item, index) => {
            return (
              <Link
                onClick={item.href === "/publicar" ? handleOpenLogin : () => { }}
                href={item.href === "/publicar" ? (isLoggedIn() ? "/publicar" : "") : getHref(item.href)}
                key={index}
                alt={item.title}
                title={item.title}
                className={`aspect-square cursor-pointer hover:bg-lightGray-HC-white hover:text-darkGray-HC-dark-underline focus:bg-lightGray-HC-white  text-center rounded-lg pt-2 w-[80px]
                  ${(page === item.href) || (pathname.startsWith(item.href)) ? "bg-lightGray-HC-white text-darkGray-HC-dark-underline font-bold" : ""}
                `}
              >
                <item.icon
                  className={`text-3xl rounded-xl cursor-pointer ${page === item.href ? "text-darkGray-HC-dark-underline font-bold" : ""}`}
                />
                <div className={`py-1 text-base ${page === item.href ? "text-darkGray-HC-dark-underline font-bold" : ""}`}>
                  {item.title}
                </div>
              </Link>
            );
          })}
        </div>
      </div>
    </>
  );
}