import { Avatar, Button, Paper } from "@mui/material";
import { useLoginBarrier } from "@/app/handlers/loginHandler";
import { useState, useEffect } from "react";
import mecredApi, { mecredURL } from "@/axiosConfig";
import { getStoredValue } from "@/app/handlers/localStorageHandler";

export default function PublisherInfo({ publisher, disabledButton = false }) {
  const [followed, setFollowed] = useState(false);

  const loginBarrier = useLoginBarrier();
  const token = getStoredValue("access_token")
  const client = getStoredValue("client")
  const uid = getStoredValue("uid")

  useEffect(() => {
    setFollowed(publisher?.followed ?? false);
  }, [publisher]);

  if (!publisher) {
    return <></>;
  }

  const followHandler = () => {
    loginBarrier();
    mecredApi.put(
      `users/${publisher.id}/follow/`,
      {},
      {
        headers: {
          "access-token": token,
          "token-type": "Bearer",
          client: client,
          uid: uid,
          Expires: 0,
        },
      }
    );
    setFollowed((old) => !old);
  };

  function getRandomBg(id) {
    const colors = [
      "bg-turquoise",
      "bg-orange",
      "bg-turquoise-hover",
      "bg-darkOrange-HC-gray ",
      "bg-violet",
      "bg-pink",
      "bg-red",
      "bg-darkGray-HC-white",
      "bg-darkGray-HC-white-click",
      "bg-ice-HC-dark ",
      "bg-darkGray-HC-white",
      "bg-darkGray-HC-white",
      "bg-turquoise-HC-dark",
    ]

    return colors[id % colors.length];
  }

  return (
    <>
      <Paper className="bg-white-HC-dark  outline outline-1 outline-ice-HC-white shadow-none flex flex-shrink-0 rounded-xl p-1 m-1 normal-case text-sm font-bold max-sm:flex-col">
        <Button href={`/perfil/${publisher.id}`} >
        <div className="flex flex-row truncate">
          {publisher?.avatar ? (
              <Avatar
                fill="true"
                src={mecredURL + publisher.avatar}
                alt="Publisher Avatar"
                title={publisher.name}
                className="m-4"
              />
          ) : (
            <div className={`flex items-center justify-center text-xl m-2 font-bold text-ice-HC-dark rounded-full h-10 w-10 ${getRandomBg(publisher.id)}`} >{publisher.name[0]}</div>
          )}
          <div className="flex flex-col justify-center p-1 text-darkGray-HC-white-underline truncate">
            <div className="font-bold text-lg truncate sm:text-wrap">
              {publisher.name}
            </div>
            <div className="font-normal text-md truncate ">
              {publisher.description}
            </div>
          </div>
        </div>
        </Button>
        <div className="flex justify-end flex-grow flex-shrink-0 p-3 truncate max-sm:justify-start">
          <Button
            disabled={disabledButton}
            href={`/perfil/${publisher.id}`}
            className="outline outline-1 outline-mediumGray-HC-white hover:bg-ice-HC-white  bg-white-HC-dark  h-12 text-darkGray-HC-white-underline hover:text-darkGray-HC-dark-underline shadow-none rounded-xl p-3 m-1 mr-3 px-8 normal-case font-bold"
          >
            Ver Perfil
          </Button>
          <Button
            disabled={disabledButton}
            onClick={followHandler}
            variant="outlined"
            className="bg-turquoise-HC-white h-12 text-white-HC-dark-underline hover:text-white-HC-underline hover:bg-darkTurquoise-HC-dark border-1 border-transparent hover:border-turquoise-HC-white shadow-none rounded-xl  m-1 px-2 sm:px-8 normal-case font-bold"
          >
            {followed ? "Seguindo" : "Seguir"}
          </Button>
        </div>
      </Paper>
    </>
  );
}
