import * as React from "react";
import Box from "@mui/material/Box";
import Button from "@mui/material/Button";
import Modal from "@mui/material/Modal";
import { TextField, Alert } from "@mui/material";
import { useState } from "react";
import mecredApi from "@/axiosConfig";
import { removeFromLocalStorage } from "@/app/handlers/localStorageHandler";
import CloseIcon from '@mui/icons-material/Close';


export default function PasswordModal({ open, handleClose }) {
  const [userEmail, setUserEmail] = useState("");
  const [feedbackMessage, setfeedbackMessage] = useState("");
  const [error, setError] = useState(false);

  // A API requer a URL para onde o usuário será redirecionado quando precisar inserir a nova senha

  // const redirect_url = "http://localhost:3000/novaSenha"
  const redirect_url = "https://mecred.mec.gov.br/novaSenha"

  /**
   * Função que envia o payload de recuperação de senha para a API
   */
  const sendRecovery = async () => {
    mecredApi
      .post("/auth/password", {
        email: userEmail,
        "redirect_url": redirect_url
      })
      .then((response) => {
        setfeedbackMessage(
          "Email de recuperação de senha enviado com sucesso."
        );
        removeFromLocalStorage("access_token");
        setError(false);
      })
      .catch((e) => {
        setfeedbackMessage(e["response"]["data"]["errors"][0]);
        setError(true);
      });

  };

  const resetForm = () => {
    setUserEmail("");
  };

  const handleSubmitPswd = () => {

    if (!userEmail) {
      setfeedbackMessage("Email obrigatório!");
      setError(true);
      resetForm();
    } else {
      sendRecovery();
    }
  };

  return (
    <Modal
      className="grid h-screen place-items-center m-5"
      open={open}
      onClose={handleClose}
      slotProps={{
        backdrop: {
          sx: {
            backgroundColor: "rgba(0, 0, 0, 0.3)", // Ajuste a opacidade conforme necessário
          },
        },
      }}
    >
      <Box className="bg-white-HC-dark outline outline-1 outline-ice-HC-white p-5 flex flex-col items-center border-none rounded-xl">
        <div className="flex flex-row justify-between mb-2">
          <h1 className="text-turquoise-HC-white  text-2xl font-bold m-2 mb-5 mr-4">Vamos encontrar sua conta</h1>
          <CloseIcon onClick={handleClose} sx={{ color: "var(--darkGray-HC-white)", fontSize: "30px", marginTop:"5px" }} />
        </div>
        <div>
          {feedbackMessage ? (
            <Alert severity={error ? "error" : "success"}>
              {feedbackMessage}
            </Alert>
          ) : null}
          <div className="w-full mb-3">
            <label htmlFor="email" className="block text-sm font-medium text-darkGray-HC-white mb-1">
              E-mail *
            </label>
            <input
              id="email"
              type="email"
              className="w-full px-5 py-2 border border-mediumGray-HC-white rounded-md focus:outline-none focus:ring-2 focus:ring-turquoise-HC-white"
              onChange={(e) => setUserEmail(e.target.value)}
              error={!userEmail && error}
              value={userEmail}
              alt="E-mail (obrigatório)"
            />
          </div>
          <Button
            fullWidth
            disableElevation
            className="bg-turquoise-HC-white text-white-HC-dark-underline hover:bg-darkTurquoise-HC-dark hover:text-white font-bold py-2 rounded-md outline outline-1 outline-ice-HC-white"
            onClick={() => handleSubmitPswd()}
            alt="Enviar"
          >
            {feedbackMessage ? "Reenviar" : "Enviar"}
          </Button>
        </div>
      </Box>
    </Modal>
  );
}
