"use client";
import Grid from "@mui/material/Unstable_Grid2";
import LoginForm from "./components/LoginForm";
import { useEffect, useState } from "react";
import mecredApi from "@/axiosConfig";
import {
  getStoredValue,
  saveToLocalStorage,
} from "../handlers/localStorageHandler";
import { redirect, useRouter, useSearchParams } from "next/navigation";
import { Suspense } from 'react';
import { ThemeProvider } from "@emotion/react";
import theme from "../theme";
import LoginInfo from "./components/LoginInfo";
import AcessibilityBar from "../components/AcessibilityBar";

function Login() {
  const [userEmail, setUserEmail] = useState("");
  const [userPassword, setUserPassword] = useState("");
  const [errorMessage, setErrorMessage] = useState("");
  const [isFirstLetterUpperCase, setIsFirstLetterUpperCase] = useState(false);
  const searchParams = useSearchParams();
  const access_token = getStoredValue("access_token");
  // Obtendo os parâmetros de busca
  const redirectUrl = searchParams.get("redirect")
    ? searchParams.get("redirect") + (searchParams.get("params") ? `?${searchParams.get("params")}` : '')
    : "/sobre"; // Redireciona para /sobre se não houver valor
  const router = useRouter();

  const handleEmailChange = (e) => {
    const emailValue = e.target.value;
    setUserEmail(emailValue);

    // Verifica se a primeira letra é maiúscula
  if (emailValue.length > 0) { 
    const firstLetter = emailValue.charAt(0);
    setIsFirstLetterUpperCase(firstLetter === firstLetter.toUpperCase());
  } else {
    setIsFirstLetterUpperCase(false);
  }
  };


  const handlePasswordChange = (e) => {
    setUserPassword(e.target.value);
  };

  const userLogin = async (event, email, password) => {
    event.preventDefault();
    await mecredApi
      .post("/auth/sign_in", {
        email: userEmail,
        password: userPassword,
      })
      .then((response) => {
        saveToLocalStorage("user_data", JSON.stringify(response.data["data"]));
        saveToLocalStorage("access_token", response.headers["access-token"]);
        saveToLocalStorage("client", response.headers["client"])
        saveToLocalStorage("uid", response.headers["uid"])
        saveToLocalStorage("expiry", response.headers["expiry"])
        saveToLocalStorage("token-type", response.headers["token-type"])
        router.push(redirectUrl);
      })
      .catch((error) => {
        setErrorMessage(error['response']['data']['errors'][0])
      })
  };

  useEffect(() => {
    if (access_token) redirect(redirectUrl);
  });

  return (
    <ThemeProvider theme={theme}>
      <Grid container className="bg-fundo bg-repeat bg-fixed min-h-screen">
        <Grid xs={12} xl={7} order={{ xs: 2, xl: 1 }}>
          <LoginInfo />
        </Grid>
        <Grid xs={12} xl={5} order={{ xs: 1, xl: 2 }}>
          <LoginForm
            handleEmailChange={handleEmailChange}
            handlePasswordChange={handlePasswordChange}
            handleSubmit={userLogin}
            errorMessage={errorMessage}
            uppercase={isFirstLetterUpperCase}
          />
        </Grid>
      </Grid>
    </ThemeProvider>
  );
}

export default function LoginWrapper() {
  return (
    <Suspense>
      <div className="text-base">
        <AcessibilityBar />
        <Login />
      </div>
    </Suspense>
  );
};