import { redirect, usePathname, useSearchParams } from "next/navigation";
import { useRouter } from "next/navigation";
import { useCallback } from "react";
import { getStoredValue } from "./localStorageHandler";

export function isLoggedIn() {
  if (typeof window === "undefined") return undefined;

  return getStoredValue("access_token") ? true : false;
}

/**
 * React Hook for forcing login. Redirects to login page and when user logs in redirects back to the original page.
 * For example, doing `const loginBarrier = useLoginBarrier()` then calling `loginBarrier()` will redirect to login page if
 * the user is not logged in. 
 * 
 * @returns Function that will force login.
 */
export function useLoginBarrier(originalPath) {
  const pathname = usePathname();
  const searchParams = useSearchParams();
  const router = useRouter();

  return useCallback(() => {
    if (isLoggedIn()) return true;

    const params = new URLSearchParams();
    params.set("redirect", pathname);
    params.set("params", searchParams.toString());
    router.push(`/entrar?${params.toString()}`);

    return false;
  }, [router, pathname, searchParams]);
}