import HorizontalLinearAlternativeLabelStepper from "./Stepper";
import { useEffect, useState } from "react";
import UploadForm from "./UploadForm";
import InfoForm from "./InfoForm";
import RevisionForm from "./RevisionForm"
import mecredApi from "@/axiosConfig";
import { getStoredValue } from "@/app/handlers/localStorageHandler";
import AdvanceNotice from "./AdvanceNotice";

export default function Form() {
  const [step, setStep] = useState(0);
  const [draft, setDraft] = useState(null);
  const [authorType, setAuthorType] = useState("a");
  const [file, setFile] = useState(null);
  const [attachmentId, setAttachmentId] = useState(null);
  const [userData, setUserData] = useState(null);
  const [thumbURL, setThumbURL] = useState(null);
  const [thumb, setThumb] = useState(null);


  const token = getStoredValue("access_token");
  const client = getStoredValue("client");
  const uid = getStoredValue("uid");
  const payload = {}

  useEffect(() => {
    const fetchData = async () => {
      try {
        setUserData(JSON.parse(getStoredValue("user_data")));

        if (draft && draft.id) {
          return;
        }

        const response = await mecredApi.post(`/learning_objects/`, payload, {
          headers: {
            "access-token": token,
            "token-type": "Bearer",
            client: client,
            uid: uid,
            Expires: 0,
          },
        });

        setDraft(response.data);
      } catch (error) {
        // Tratar erros, se necessário
        console.error('Erro ao enviar dados:', error);
      }
    };

    fetchData();
  }, [client, token, uid, draft]);


  return (
    <>
      <div className="flex flex-col justify-start w-full mt-15 max-sm:mx-0 max-md:mb-16 overflow-auto scrollbar-none">
        <HorizontalLinearAlternativeLabelStepper step={step}  />
        {step === 0 && userData && <InfoForm userData={userData} setStep={setStep} draft={draft} setDraft={setDraft} authorType={authorType} setAuthorType={setAuthorType} />}
        {step === 1 && <UploadForm thumbURL={thumbURL} setThumbURL={setThumbURL} thumb={thumb} setThumb={setThumb} setStep={setStep} draft={draft} setDraft={setDraft} file={file} setFile={setFile} attachmentId={attachmentId} setAttachmentId={setAttachmentId} />}
        {step === 2 && <RevisionForm setStep={setStep} draft={draft} setDraft={setDraft} />}
        <AdvanceNotice />
      </div>
    </>
  );
}
