import Backdrop from '@mui/material/Backdrop';
import Modal from '@mui/material/Modal';
import CloseIcon from '@mui/icons-material/Close';
import { IconButton } from '@mui/material';
import * as React from 'react';
import Accordion from '@mui/material/Accordion';
import AccordionSummary from '@mui/material/AccordionSummary';
import AccordionDetails from '@mui/material/AccordionDetails';
import ExpandMoreIcon from '@mui/icons-material/ExpandMore';

const whyLicense = [
    {
        name: "Facilita o compartilhamento e a colaboração",
        details: "Com a Creative Commons, incentivamos a criação de uma comunidade colaborativa onde o conteúdo pode ser compartilhado, modificado e reutilizado, sempre de forma transparente e com respeito aos direitos de quem criou o material original."
    },
    {
        name: "Respeito à autoria e créditos",
        details: "As licenças Creative Commons exigem que dêem crédito ao autor original sempre que o conteúdo for utilizado. Isso garante que os criadores sejam reconhecidos pelo seu trabalho, sem perder o controle sobre o uso indevido."
    },
    {
        name: "Transparência e legalidade",
        details: "Ao usar Creative Commons, garantimos que os usuários saibam exatamente como podem usar o conteúdo. Isso ajuda a evitar mal-entendidos e uso não autorizado, promovendo um ambiente legalmente seguro tanto para quem cria quanto para quem usa o material."
    },
    {
        name: "Flexibilidade para os usuários",
        details: "Dependendo do tipo de licença, as pessoas podem adaptar, remixar ou distribuir o conteúdo, desde que respeitem os termos da licença (como atribuição de crédito ou não uso comercial). Isso oferece uma grande flexibilidade para diversos tipos de utilização."
    }
]

const ccLicense = [
    {
        name: "CC BY",
        details: " Permite que outros compartilhem, copiem e modifiquem, desde que o autor original seja creditado."
    }, {
        name: "CC BY-SA",
        details: " Permite modificações, mas qualquer obra derivada deve ser licenciada sob a mesma licença."
    }, {
        name: "CC BY-NC ",
        details: " Permite uso e modificação, mas não para fins comerciais."
    }, {
        name: "CC BY-NC-SA",
        details: " Permite que outros modifiquem e compartilhem o conteúdo para fins não comerciais, desde que atribuam o crédito e compartilhem as modificações sob a mesma licença."
    }, {
        name: "CC BY-NC-ND ",
        details: " Permite que outros compartilhem o conteúdo para fins não comerciais, desde que não modifiquem a obra e atribuam o crédito ao autor."
    }
]
export default function LicenseModal({ openModal, onClose }) {


    return (

        <Modal
            className='flex justify-center items-stretch m-4 '
            aria-labelledby="transition-modal-title"
            aria-describedby="transition-modal-description"
            open={openModal}
            onClose={onClose}
            closeAfterTransition
            slots={{ backdrop: Backdrop }}
            slotProps={{
                backdrop: {
                    timeout: 500,
                    backgroundColor: "rgba(0, 0, 0, 0.3)", // Ajuste a opacidade conforme necessário
                },
            }}
            
        >
            <div className='absolute w-4/5 h-4/5 overflow-auto p-4 pb-14 rounded-lg text-darkGray-HC-white self-center bg-white-HC-dark  border-2 border-ice-HC-white'>
                <>
                    <div className='group flex justify-end'>
                        <IconButton onClick={onClose} className='group-hover:bg-ice-HC-white'>
                            <CloseIcon
                                fontSize='large'
                                className='text-darkGray-HC-white group-hover:text-darkGray-HC-dark'
                            />
                        </IconButton>
                    </div>
                    <p className='text-darkGray-HC-white text-xl text-center font-semibold pb-4'>
                        Por que usamos licenças no MEC-RED?
                    </p>
                    <p className='text-base text-center'>
                        Nós utilizamos a licença Creative Commons para garantir que nosso conteúdo (imagens, textos, vídeos, etc.)
                        seja acessível, compartilhável e utilizável por todos, enquanto respeitamos os direitos autorais e a autoria
                        original. A Creative Commons é uma licença que permite que outras pessoas usem, compartilhem ou adaptem o
                        conteúdo de forma legal, desde que sigam algumas condições específicas.
                    </p>

                    <p className='text-darkGray-HC-white text-lg text-center font-semibold py-4 pt-10'>
                        A importância da Creative Commons:
                    </p>
                    {whyLicense.map((license) => (
                        < Accordion  key={license.name} className='bg-white-HC-dark outline outline-1 outline-lightGray-HC-white'>
                            <AccordionSummary
                                expandIcon={<ExpandMoreIcon className="text-darkGray-HC-white"/>}
                                aria-controls="panel1-content"
                                id="panel1-header"
                            >
                                <p className='text-darkGray-HC-white font-semibold'>{license.name}</p>
                            </AccordionSummary>
                            <AccordionDetails className='text-darkGray-HC-white'> {license.details} </AccordionDetails>
                        </Accordion>))}

                    <p className='text-darkGray-HC-white text-lg text-center font-semibold py-4 pt-16 '>
                        Licenças da Creative Commons usadas no MEC-RED
                    </p>
                    {ccLicense.map((license) => (
                        <div key={license.name} className='text-darkGray-HC-white flex flex-row py-2'>
                            <p className='font-bold inline'>{license.name}:  <span className='pl-1 font-normal'> {license.details} </span> </p>
                           
                        </div>
                    ))}

                </>
            </div>
        </Modal >
    );
}
