"use client"
import mecredApi from "@/axiosConfig"
import { Button, Paper } from "@mui/material"
import { getStoredValue } from "@/app/handlers/localStorageHandler";
import { useEffect, useState } from "react";
import Tags from "@/app/components/tags";
import PublisherInfo from "@/app/components/publisherInfo";
import ResourceInfo from "@/app/recurso/[id]/components/resourceInfo";
import ResourcePreview from "@/app/recurso/[id]/components/resourcePreview";
import ModalSuccess from "./ModalSuccess";
import { useRouter } from "next/navigation";
import CancelSubmitModal from "./CancelSubmitModal";

function headerConfig() {
    return {
        headers: {
            "access-token": getStoredValue("access_token"),
            "token-type": "Bearer",
            client: getStoredValue("client"),
            uid: getStoredValue("uid"),
            Expires: 0,
        }
    };
}

export default function RevisionForm({ setStep, draft, setDraft }) {
    const [permission, setPermission] = useState(false)
    const [openModal, setOpenModal] = useState(false)

    const [openModalCancel, setOpenModalCancel] = useState(false)

    let userData = JSON.parse(getStoredValue("user_data"))
    const router = useRouter();

    /// Ira ser enviado ao backend
    let data = {
        attachmentID: draft.attachmentID,
        file: draft.file,
        name: draft.name,
        description: draft.description,
        tags: draft.tags.map(tag => { return { name: tag } }),
        author: draft.author,
        object_type_id: draft.object_type_f[0].id,
        language_ids: draft.language_ids,
        language_names: draft.language,
        educational_stages: draft.educational_stages,
        subjects: draft.subjects.map(subj => { return subj.id }),
        license_id: draft.license_id,
        link: draft.link,
    }

    /// Irá ser enviado ao componente de visualizacao para preview
    let preview = {
        ...draft,
        default_mime_type: draft.attachments[0]?.mime_type,
        object_type: draft.object_type_f[0]?.name,
        language: draft.language.map(lang => { return { name: lang } }),
        tags: draft.tags.map(tag => { return { name: tag } }),
        subjects: draft.subjects.map(subject => { return { name: subject.name } }),
        educational_stages: draft.educational_stages_name.map(educa => { return { name: educa } })
    }

    useEffect(() => {
        mecredApi.get("/learning_objects/" + draft.id, headerConfig())
            .then((response) => {
                setDraft(curr => {
                    return { ...curr, attachments: response.data.attachments }
                })
            });

    }, [draft.id, setDraft])

    useEffect(() => {

        for (let i = 0; i < userData.roles.length; i++) {
            if (userData.roles[i].name === "partner" || userData.roles[i].name === "admin") {
                setPermission(true)
                return
            }
        }

    }, [userData.roles])



    const submitHomologation = () => {

        mecredApi
            .put(`/learning_objects/${draft.id}`, data, headerConfig())
            .then(
                () => {

                    let payload = {
                        "submission": {
                            "learning_object_id": draft.id
                        }
                    }

                    return (
                        mecredApi
                            .post("/submissions", payload, headerConfig())
                    )
                }
            )
            .then(
                setOpenModal(true)
            )

    }

    const fetchSubmit = () => {

        mecredApi
            .put(`/learning_objects/${draft.id}`, data, headerConfig())
            .then(
                () =>
                    mecredApi
                        .post(`/learning_objects/${draft.id}/publish`, {}, headerConfig())
            )
            .then(
                setOpenModal(true)
            )
            .catch((error) => (console.error(error)))
    }

    return (
        <>
            <ModalSuccess
                openModal={openModal}
                onClose={() => {
                    setOpenModal(false);
                    router.push("/busca?page=LearningObject");
                }}
                permission={permission} 
                idResource={draft.id}
                />

            <form>
                <Paper 
                    className="rounded-lg p-10 max-xl:mx-5 mx-5"
                    elevation={1}
                    sx={{
                        backgroundColor: 'var(--white-HC-dark)',
                        border: '2px solid var(--ice-HC-white)',
                    }}
                    >
                    <div className="flex flex-col text-center py-6">
                        <p className="text-2xl text-darkGray-HC-white pb-6">
                            Quase lá, agora só falta revisar e submeter!
                        </p>
                        <p className="text-lg text-darkGray-HC-white">
                            Veja abaixo como o seu Recurso vai aparecer na MEC RED:
                        </p>
                    </div>
                </Paper>



                {/* Pré-visualização página de recurso */}
                <div className="flex flex-col lg:flex-row justify-center  mt-4 mb-6 rounded-md">
                    <div className="flex flex-col bg-ice-HC-dark p-3 lg:w-[98%] flex-shrink-0 mt-4 mb-4 ">
                        <div className=" flex justify-center">
                            {/* Pré-visualização */}
                            <ResourcePreview learningObject={preview} />
                        </div>
                        <div className="text-darkGray-HC-white mt-5 text-2xl font-bold">
                            {/* Título */}
                            <h1>{draft.name}</h1>
                        </div>
                        <div className="text-darkGray-HC-white mt-3 text-sm font-bold">
                            {/* tags */}
                            <Tags tags={preview.tags} />
                        </div>
                        <div className="">
                            {/* Publicador */}
                            <PublisherInfo publisher={draft?.publisher} disabledButton={true} />
                        </div>
                        <div className="">
                            {/* Informações */}
                            <ResourceInfo learningObject={preview} />
                        </div>
                    </div>
                </div>



                <div className="flex w-full justify-end p-5">
                    <Button
                        onClick={() => setOpenModalCancel(true)}
                        type="button"
                        variant="text"
                        className="normal-case w-36 mr-2 text-base text-darkGray-HC-white-underline font-bold outline outline-1 outline-ice-HC-white hover:bg-lightGray-HC-white hover:text-darkGray-HC-dark-underline"
                    >
                        Cancelar
                    </Button>
                    <Button
                        variant="text"
                        className="normal-case w-36 mr-2 text-base text-darkGray-HC-white-underline font-bold outline outline-1 outline-ice-HC-white hover:bg-lightGray-HC-white hover:text-darkGray-HC-dark-underline"
                        onClick={() => setStep(curr => curr - 1)}
                    >
                        Voltar
                    </Button>
                    {permission ?
                        <Button
                            className="w-36 rounded-lg hover:bg-turquoise-hover border-turquoise-HC-white hover:bg-darkTurquoise-HC-dark bg-turquoise-HC-white text-base text-white-HC-dark-underline hover:text-white-HC-underline font-bold normal-case flex "
                            variant="outlined"
                            onClick={fetchSubmit}
                        >
                            Publicar
                        </Button>

                        :

                        <Button
                            className=" border-secondary w-36 rounded-lg hover:bg-turquoise-hover bg-turquoise text-base text-white-HC-dark-underline font-bold normal-case flex "
                            variant="outlined"
                            onClick={submitHomologation}
                        >
                            Submeter
                        </Button>

                    }

                </div>
            </form>
            <CancelSubmitModal openModal={openModalCancel} onClose={() => { setOpenModalCancel(false) }} />
        </>
    )
}