import { Button } from "@mui/material";
import FieldLabel from "./FieldLabel";
import { useState } from "react";
import Image from "next/image";
import ErrorSize from "./ErrorSize";
import { imageType } from "@/app/components/FileTypeUtilities";
import ErrorType from "./ErrorType";



export default function SubmitThumbnail({ error, setThumb, thumbURL, setThumbURL, draft, setDraft }) {
    const [open, setOpen] = useState(false)
    const [openType, setOpenType] = useState(false)


    const handleThumbnail = (e) => {
        if (!imageType(e.target.files[0]?.type)) {
            e.target.files = null
            setOpenType(true)
            return
        }

        if (e.target.files[0].size > 4e6) {
            e.target.files = null
            setOpen(true)
            return
        }

        e.preventDefault()
        setThumb(e.target.files[0]);
        setThumbURL(URL.createObjectURL(e.target.files[0]));
    };


    return (
        <>
            <FieldLabel
                name="Imagem Ilustrativa do Recurso*"
                description="Deixe seu recurso completo, para que todos o entendam melhor."
                error={error}
            />
            <ErrorSize open={open} handleClose={() => setOpen(false)} maxSize="4MB" />
            <ErrorType open={openType} handleClose={() => setOpenType(false)} thumbnail={true} />

            <div className="flex flex-col items-center mb-10 ">

                {thumbURL &&
                    <>
                        <FieldLabel
                            description="Imagem selecionada:"
                        />
                        <div className="relative aspect-video w-[55%] mb-10 mt-0 border-solid border-2 border-main rounded-lg">
                            <Image sizes="90vw"
                                fill
                                style={{
                                    borderRadius: '10px',
                                    width: '100%',
                                    objectFit: 'cover'
                                }} src={`${thumbURL}`} alt="imagem thumbnail" />
                        </div>
                    </>
                }
                <p className="text-center text-sm text-darkGray-HC-white pb-1"> A imagem pode ter o tamanho máximo de 4MB </p>

                <Button
                    variant="outlined"
                    component="label"
                    className="text-white-HC-dark-underline font-bold px-10 rounded-lg w-64 hover:text-white-HC-underline bg-turquoise-HC-white hover:bg-darkTurquoise-HC-dark border-1 border-transparent hover:border-turquoise-HC-white"
                >
                    {thumbURL ? "Trocar Thumbnail" : "Adicionar thumbnail"}
                    <input type="file" hidden onChange={handleThumbnail} />
                </Button>


            </div>


        </>
    )
}